(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{17:function(e,t,n){e.exports=n(25)},25:function(e,t,n){"use strict";n.r(t);var a=n(8),r=n.n(a),c=n(15),o=n.n(c),s=n(6),i=n(0),u=n(1),l=n(2),p=n(3),m=n(13),d=function(e){Object(l.a)(n,e);var t=Object(p.a)(n);function n(e){var a;Object(u.a)(this,n),(a=t.call(this,e)).render=function(){return r.a.createElement("p",null,"HBJSON")},a._readHBJSON=function(){var e,t=a.state.delay;(e=t,new Promise((function(t,n){return setTimeout((function(){var e=window.parent.chrome.webview.hostObjects.sync.hbjson.PassHBJSON();t(e)}),e)}))).then((function(e){m.a.setComponentValue(e)}))};var c={delay:a.props.args.delay};return a.state=Object(s.a)({},c),window.parent.readHBJSON=a._readHBJSON,a}return Object(i.a)(n)}(m.b),b=Object(m.c)(d);o.a.render(r.a.createElement(r.a.StrictMode,null,r.a.createElement(b,null)),document.getElementById("root"))}},[[17,1,2]]]);
//# sourceMappingURL=main.9b8d4550.chunk.js.map